<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa_IR">
  <context>
    <name>ConfigDialog</name>
    <message>
      <location filename="../config.py" line="86" />
      <source>Using configuration file at:</source>
      <translation>استفاده از پروندهٔ تنظیمات در نشانی:</translation>
    </message>
    <message>
      <location filename="../config.py" line="105" />
      <source>Behavior</source>
      <translation>رفتار</translation>
    </message>
    <message>
      <location filename="../config.py" line="106" />
      <source>Automatically save documents</source>
      <translation>ذخیرهٔ خودکار سندها</translation>
    </message>
    <message>
      <location filename="../config.py" line="107" />
      <source>Automatically open last documents on startup</source>
      <translation>باز کردن خودکار آخرین اسناد در هنگام ورود به برنامه</translation>
    </message>
    <message>
      <location filename="../config.py" line="108" />
      <source>Number of recent documents</source>
      <translation>تعداد اسناد به خاطر سپردهٔ اخیر</translation>
    </message>
    <message>
      <location filename="../config.py" line="109" />
      <source>Restore window geometry</source>
      <translation>بازیابی اندازهٔ قبلی پنجره</translation>
    </message>
    <message>
      <location filename="../config.py" line="110" />
      <source>Default preview state</source>
      <translation>وضعیّت نمایش پیش‌فرض</translation>
    </message>
    <message>
      <location filename="../config.py" line="111" />
      <source>Open external links in ReText window</source>
      <translation>باز کردن پیوندهای خارجی در پنجرهٔ ReText</translation>
    </message>
    <message>
      <location filename="../config.py" line="112" />
      <source>Markdown syntax extensions (comma-separated)</source>
      <translation>افزونه‌های قواعد Markdown ( با کاما «,» از هم جدا نوشته شوند)</translation>
    </message>
    <message>
      <location filename="../config.py" line="114" />
      <source>Enable synchronized scrolling for Markdown</source>
      <translation>فعّال‌سازی پیمایش هم‌زمان برای Markdown </translation>
    </message>
    <message>
      <location filename="../config.py" line="179" />
      <location filename="../config.py" line="118" />
      <source>Editor</source>
      <translation>ویرایشگر</translation>
    </message>
    <message>
      <location filename="../config.py" line="119" />
      <source>Highlight current line</source>
      <translation>مشخّص کردن سطر کنونی</translation>
    </message>
    <message>
      <location filename="../config.py" line="120" />
      <source>Show line numbers</source>
      <translation>نمایش شمارهٔ سطرها</translation>
    </message>
    <message>
      <location filename="../config.py" line="121" />
      <source>Line numbers are relative to current line</source>
      <translation>نمایش شمارهٔ سطرها نسبت به سطر کنونی</translation>
    </message>
    <message>
      <location filename="../config.py" line="122" />
      <source>Tab key inserts spaces</source>
      <translation>تنظیم Tab برای قرار دادن فاصله</translation>
    </message>
    <message>
      <location filename="../config.py" line="123" />
      <source>Tabulation width</source>
      <translation>عرض جدول‌بندی</translation>
    </message>
    <message>
      <location filename="../config.py" line="124" />
      <source>Draw vertical line at column</source>
      <translation>کشیدن خط عمودی در ستون شمارۀ</translation>
    </message>
    <message>
      <location filename="../config.py" line="125" />
      <source>Enable soft wrap</source>
      <translation>فعّال‌سازی حالت گنجاندن تمام متن در محیط قابل نمایش</translation>
    </message>
    <message>
      <location filename="../config.py" line="126" />
      <source>Show document stats</source>
      <translation>نمایش آمار سند</translation>
    </message>
    <message>
      <location filename="../config.py" line="127" />
      <source>Ordered list mode</source>
      <translation>حالت فهرست ترتیبی</translation>
    </message>
    <message>
      <location filename="../config.py" line="129" />
      <source>Interface</source>
      <translation>ظاهر</translation>
    </message>
    <message>
      <location filename="../config.py" line="130" />
      <source>Hide toolbar</source>
      <translation>نهفتن نوار ابزار</translation>
    </message>
    <message>
      <location filename="../config.py" line="131" />
      <source>Icon theme name</source>
      <translation>نام مضمون آیکون</translation>
    </message>
    <message>
      <location filename="../config.py" line="132" />
      <source>Stylesheet file</source>
      <translation>پروندهٔ قالب</translation>
    </message>
    <message>
      <location filename="../config.py" line="133" />
      <source>Hide tabs bar when there is only one tab</source>
      <translation>نهفتن نوار سربرگ‌ها هنگامی که فقط یک سربرگ هست</translation>
    </message>
    <message>
      <location filename="../config.py" line="134" />
      <source>Show full path in window title</source>
      <translation>نمایش مسیر کامل در نوار عنوان</translation>
    </message>
    <message>
      <location filename="../config.py" line="135" />
      <source>Show directory tree</source>
      <translation>نمایش درختی مسیر</translation>
    </message>
    <message>
      <location filename="../config.py" line="136" />
      <source>Working directory</source>
      <translation>مسیر اجرا</translation>
    </message>
    <message>
      <location filename="../config.py" line="161" />
      <source>Help</source>
      <translation>کمک</translation>
    </message>
    <message>
      <location filename="../config.py" line="180" />
      <source>Live preview</source>
      <translation> پیش‌نمایش زنده</translation>
    </message>
    <message>
      <location filename="../config.py" line="181" />
      <source>Normal preview</source>
      <translation>پیش‌نمایش عادی</translation>
    </message>
    <message>
      <location filename="../config.py" line="186" />
      <source>Disabled</source>
      <translation>غیرفعّال</translation>
    </message>
    <message>
      <location filename="../config.py" line="187" />
      <source>Cursor Line</source>
      <translation>مکان‌نما</translation>
    </message>
    <message>
      <location filename="../config.py" line="188" />
      <source>Wrapped Line</source>
      <translation>پوشش سطر</translation>
    </message>
    <message>
      <location filename="../config.py" line="193" />
      <source>Increment</source>
      <translation>افزایش</translation>
    </message>
    <message>
      <location filename="../config.py" line="194" />
      <source>Repeat</source>
      <translation>تکرار</translation>
    </message>
  </context>
  <context>
    <name>DirectorySelectButton</name>
    <message>
      <location filename="../config.py" line="61" />
      <source>Select directory to open</source>
      <translation>انتخاب مسیر برای باز کردن</translation>
    </message>
  </context>
  <context>
    <name>EncodingDialog</name>
    <message>
      <location filename="../dialogs.py" line="63" />
      <source>Enter encoding name:</source>
      <translation>وارد کردن نظام نویسه</translation>
    </message>
  </context>
  <context>
    <name>FileDialogButton</name>
    <message>
      <location filename="../config.py" line="35" />
      <source>(none)</source>
      <translation>(هیچ کدام)</translation>
    </message>
  </context>
  <context>
    <name>FileSelectButton</name>
    <message>
      <location filename="../config.py" line="53" />
      <source>Select file to open</source>
      <translation>انتخاب پرونده برای باز کردن</translation>
    </message>
  </context>
  <context>
    <name>InsertTableDialog</name>
    <message>
      <location filename="../tabledialog.py" line="27" />
      <source>Insert table</source>
      <translation>درج جدول</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="36" />
      <source>Number of rows</source>
      <translation>شمار ردیف‌ها</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="37" />
      <source>Number of columns</source>
      <translation>شمار ستون‌ها</translation>
    </message>
  </context>
  <context>
    <name>LocaleDialog</name>
    <message>
      <location filename="../dialogs.py" line="43" />
      <source>Enter locale name (example: en_US)</source>
      <translation>ورود نام زبان محلّی ( مثلاً: en_US )</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="44" />
      <source>It is possible to specify multiple languages, separated by comma.</source>
      <translation>می‌توان چند زبان مختلف را تعریف کرد،
با ویرگول از هم جدا شوند.</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="50" />
      <source>Set as default</source>
      <translation>تعیین به عنوان پیش‌فرض</translation>
    </message>
  </context>
  <context>
    <name>Proxy</name>
    <message>
      <location filename="../fakevimeditor.py" line="62" />
      <source>No write since last change (add ! to override)</source>
      <translation>از زمان ذخیرهٔ قبلی چیزی نوشته نشده (برای نادیده گرفتن چیزی اضافه کنید!)</translation>
    </message>
    <message>
      <location filename="../fakevimeditor.py" line="118" />
      <source>Information</source>
      <translation>اطّلاعات</translation>
    </message>
  </context>
  <context>
    <name>ReTextEdit</name>
    <message>
      <location filename="../editor.py" line="252" />
      <source>Add to dictionary</source>
      <translation>افزودن به فرهنگ لغت</translation>
    </message>
    <message>
      <location filename="../editor.py" line="464" />
      <source>Save image</source>
      <translation>ذخیرهٔ تصویر</translation>
    </message>
    <message>
      <location filename="../editor.py" line="466" />
      <source>Images (*.png *.jpg)</source>
      <translation>تصاویر (*.png *.jpg)</translation>
    </message>
  </context>
  <context>
    <name>ReTextTab</name>
    <message>
      <location filename="../tab.py" line="174" />
      <source>New document</source>
      <translation>سند جدید</translation>
    </message>
    <message>
      <location filename="../tab.py" line="179" />
      <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
      <translation>امکان تجزیه و تحلیل محتوای پرونده نبود. بررسی کنید که آیا &lt;a href="%s"&gt;پیمانهٔ لازم  &lt;/a&gt; برای این کار را نصب کرده‌اید یا نه.</translation>
    </message>
    <message>
      <location filename="../tab.py" line="489" />
      <source>Create missing file?</source>
      <translation>پرونده گم شده ایجاد شود؟</translation>
    </message>
    <message>
      <location filename="../tab.py" line="490" />
      <source>The file '%s' does not exist.

Do you want to create it?</source>
      <translation>پروندهٔ  '%s' وجود ندارد.

آیا می خواهید آن را ایجاد کنید؟</translation>
    </message>
    <message>
      <location filename="../tab.py" line="522" />
      <source>File could not be created</source>
      <translation>امکان ایجاد پرونده نبود.</translation>
    </message>
    <message>
      <location filename="../tab.py" line="523" />
      <source>Could not create file '%s': %s</source>
      <translation>امکان ایجاد پرونده '%s': %s نبود</translation>
    </message>
  </context>
  <context>
    <name>ReTextWindow</name>
    <message>
      <location filename="../window.py" line="91" />
      <source>File toolbar</source>
      <translation>نوار ابزار پرونده</translation>
    </message>
    <message>
      <location filename="../window.py" line="93" />
      <source>Edit toolbar</source>
      <translation>نوار ابزار ویرایش</translation>
    </message>
    <message>
      <location filename="../window.py" line="95" />
      <source>Search toolbar</source>
      <translation>نوار ابزار جستجو</translation>
    </message>
    <message>
      <location filename="../window.py" line="99" />
      <source>New</source>
      <translation>جدید</translation>
    </message>
    <message>
      <location filename="../window.py" line="101" />
      <source>Open</source>
      <translation>باز کردن</translation>
    </message>
    <message>
      <location filename="../window.py" line="103" />
      <source>Set encoding</source>
      <translation>تعیین نظام نویسه</translation>
    </message>
    <message>
      <location filename="../window.py" line="1187" />
      <location filename="../window.py" line="106" />
      <source>Reload</source>
      <translation>بارگذاری دوباره</translation>
    </message>
    <message>
      <location filename="../window.py" line="109" />
      <source>Save</source>
      <translation>ذخیره</translation>
    </message>
    <message>
      <location filename="../window.py" line="112" />
      <source>Save as</source>
      <translation>ذخیره به عنوان</translation>
    </message>
    <message>
      <location filename="../window.py" line="114" />
      <source>Next tab</source>
      <translation>سربرگ بعدی</translation>
    </message>
    <message>
      <location filename="../window.py" line="116" />
      <source>Previous tab</source>
      <translation>سربرگ قبلی</translation>
    </message>
    <message>
      <location filename="../window.py" line="118" />
      <source>Close tab</source>
      <translation>بستن سربرگ</translation>
    </message>
    <message>
      <location filename="../window.py" line="120" />
      <source>Print</source>
      <translation>چاپ</translation>
    </message>
    <message>
      <location filename="../window.py" line="122" />
      <source>Print preview</source>
      <translation>پیش‌نمایش چاپ</translation>
    </message>
    <message>
      <location filename="../window.py" line="124" />
      <source>View HTML code</source>
      <translation>نمایش کد HTML </translation>
    </message>
    <message>
      <location filename="../window.py" line="125" />
      <source>Change editor font</source>
      <translation>تغییر رسم الخطّ ویرایشگر</translation>
    </message>
    <message>
      <location filename="../window.py" line="127" />
      <source>Change preview font</source>
      <translation>تغییر رسم الخطّ پیش‌نمایش</translation>
    </message>
    <message>
      <location filename="../window.py" line="129" />
      <source>Find text</source>
      <translation>یافتن متن</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <location filename="../window.py" line="131" />
      <source>Go to line</source>
      <translation>رفتن به خط شمارهٔ</translation>
    </message>
    <message>
      <location filename="../window.py" line="134" />
      <source>Preview</source>
      <translation>پیش‌نمایش</translation>
    </message>
    <message>
      <location filename="../window.py" line="144" />
      <source>Live preview</source>
      <translation>پیش‌نمایش زنده</translation>
    </message>
    <message>
      <location filename="../window.py" line="148" />
      <source>Insert table</source>
      <translation>درج جدول</translation>
    </message>
    <message>
      <location filename="../window.py" line="150" />
      <source>Table editing mode</source>
      <translation>حالت ویرایش جدول</translation>
    </message>
    <message>
      <location filename="../window.py" line="153" />
      <source>Insert images by file path</source>
      <translation>درج تصویر با استفاده از مسیر پرونده</translation>
    </message>
    <message>
      <location filename="../window.py" line="156" />
      <source>FakeVim mode</source>
      <translation>حالت تقلید از ویرایشگر Vim</translation>
    </message>
    <message>
      <location filename="../window.py" line="161" />
      <source>Fullscreen mode</source>
      <translation>حالت تمام صفحه</translation>
    </message>
    <message>
      <location filename="../window.py" line="649" />
      <location filename="../window.py" line="164" />
      <source>Preferences</source>
      <translation>تنظیمات</translation>
    </message>
    <message>
      <location filename="../window.py" line="171" />
      <source>Quit</source>
      <translation>خروج</translation>
    </message>
    <message>
      <location filename="../window.py" line="174" />
      <source>Undo</source>
      <translation>باطل کردن</translation>
    </message>
    <message>
      <location filename="../window.py" line="176" />
      <source>Redo</source>
      <translation>انجام دوباره</translation>
    </message>
    <message>
      <location filename="../window.py" line="178" />
      <source>Copy</source>
      <translation>رونوشت</translation>
    </message>
    <message>
      <location filename="../window.py" line="180" />
      <source>Cut</source>
      <translation>برش</translation>
    </message>
    <message>
      <location filename="../window.py" line="182" />
      <source>Paste</source>
      <translation>چسباندن</translation>
    </message>
    <message>
      <location filename="../window.py" line="184" />
      <source>Paste image</source>
      <translation>چسباندن تصویر</translation>
    </message>
    <message>
      <location filename="../window.py" line="186" />
      <source>Move line up</source>
      <translation>یک خط بالا رفتن</translation>
    </message>
    <message>
      <location filename="../window.py" line="188" />
      <source>Move line down</source>
      <translation>یک خط پایین رفتن</translation>
    </message>
    <message>
      <location filename="../window.py" line="196" />
      <source>Enable</source>
      <translation>فعّال‌سازی</translation>
    </message>
    <message>
      <location filename="../window.py" line="197" />
      <source>Set locale</source>
      <translation>تعیین زبان محلّی</translation>
    </message>
    <message>
      <location filename="../window.py" line="198" />
      <source>Use WebEngine (Chromium) renderer</source>
      <translation>استفاده از موتور WebEngine (Chromium) برای تهیّهٔ خروجی</translation>
    </message>
    <message>
      <location filename="../window.py" line="204" />
      <source>Show directory</source>
      <translation>نمایش دایرکتوری</translation>
    </message>
    <message>
      <location filename="../window.py" line="205" />
      <source>Next</source>
      <translation>بعدی</translation>
    </message>
    <message>
      <location filename="../window.py" line="207" />
      <source>Previous</source>
      <translation>قبلی</translation>
    </message>
    <message>
      <location filename="../window.py" line="209" />
      <source>Replace</source>
      <translation>جایگزینی</translation>
    </message>
    <message>
      <location filename="../window.py" line="211" />
      <source>Replace all</source>
      <translation>جایگزینی همه</translation>
    </message>
    <message>
      <location filename="../window.py" line="214" />
      <source>Close</source>
      <translation>بستن</translation>
    </message>
    <message>
      <location filename="../window.py" line="218" />
      <source>Get help online</source>
      <translation>دریافت کمک برخط</translation>
    </message>
    <message>
      <location filename="../window.py" line="219" />
      <source>What's new</source>
      <translation>چیزهای نوین</translation>
    </message>
    <message>
      <location filename="../window.py" line="220" />
      <source>About ReText</source>
      <translation>دربارهٔ ReText</translation>
    </message>
    <message>
      <location filename="../window.py" line="223" />
      <source>About Qt</source>
      <translation>دربارهٔ Qt</translation>
    </message>
    <message>
      <location filename="../window.py" line="238" />
      <source>Bold</source>
      <translation>ضخیم</translation>
    </message>
    <message>
      <location filename="../window.py" line="240" />
      <source>Italic</source>
      <translation>کج</translation>
    </message>
    <message>
      <location filename="../window.py" line="242" />
      <source>Underline</source>
      <translation>زیر خط‌دار</translation>
    </message>
    <message>
      <location filename="../window.py" line="315" />
      <location filename="../window.py" line="251" />
      <source>Formatting</source>
      <translation>قالب‌بندی</translation>
    </message>
    <message>
      <location filename="../window.py" line="255" />
      <source>Symbols</source>
      <translation>نمادها</translation>
    </message>
    <message>
      <location filename="../window.py" line="260" />
      <source>&amp;File</source>
      <translation>پرونده</translation>
    </message>
    <message>
      <location filename="../window.py" line="261" />
      <source>&amp;Edit</source>
      <translation>ویرایش</translation>
    </message>
    <message>
      <location filename="../window.py" line="262" />
      <source>&amp;Help</source>
      <translation>کمک</translation>
    </message>
    <message>
      <location filename="../window.py" line="265" />
      <source>Open recent</source>
      <translation>باز کردن موارد اخیر</translation>
    </message>
    <message>
      <location filename="../window.py" line="278" />
      <source>Export</source>
      <translation>صدور خروجی</translation>
    </message>
    <message>
      <location filename="../window.py" line="303" />
      <source>Spell check</source>
      <translation>بررسی املایی</translation>
    </message>
    <message>
      <location filename="../window.py" line="312" />
      <source>Default markup</source>
      <translation>نشانه‌گذاری پیش‌فرض</translation>
    </message>
    <message>
      <location filename="../window.py" line="360" />
      <source>Search</source>
      <translation>جستجو</translation>
    </message>
    <message>
      <location filename="../window.py" line="363" />
      <source>Replace with</source>
      <translation>جایگزینی با</translation>
    </message>
    <message>
      <location filename="../window.py" line="365" />
      <source>Case sensitively</source>
      <translation>حسّاسیّت نسبت به حروف بزرگ و کوچک</translation>
    </message>
    <message>
      <location filename="../window.py" line="552" />
      <location filename="../window.py" line="506" />
      <source>New document</source>
      <translation>سند جدید</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <source>Type the line number</source>
      <translation>تایپ شمارهٔ سطر</translation>
    </message>
    <message>
      <location filename="../window.py" line="737" />
      <source>Please, save the file somewhere.</source>
      <translation>لطفاً پرونده را در محلّی ذخیره کنید.</translation>
    </message>
    <message>
      <location filename="../window.py" line="856" />
      <source>Select one or several files to open</source>
      <translation>یک یا چند پرونده را برای باز کردن انتخاب کنید</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>Supported files</source>
      <translation>پرونده‌های پشتیبانی شده</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>All files (*)</source>
      <translation>همهٔ پرونده‌ها  (*)</translation>
    </message>
    <message>
      <location filename="../window.py" line="912" />
      <source>Plain text (*.txt)</source>
      <translation>متن ساده (*.txt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="915" />
      <source>%s files</source>
      <comment>Example of final string: Markdown files</comment>
      <translation>پرونده %s</translation>
    </message>
    <message>
      <location filename="../window.py" line="984" />
      <location filename="../window.py" line="928" />
      <source>Save file</source>
      <translation>ذخیرهٔ پرونده</translation>
    </message>
    <message>
      <location filename="../window.py" line="936" />
      <source>Cannot save to file which is open in another tab!</source>
      <translation>امکان ذخیرهٔ پرونده‌ای که در سربرگ دیگری باز شده نیست!</translation>
    </message>
    <message>
      <location filename="../window.py" line="974" />
      <source>Export document to ODT</source>
      <translation>صدور خروجی سند به قالب پروندهٔ ODT</translation>
    </message>
    <message>
      <location filename="../window.py" line="975" />
      <source>OpenDocument text files (*.odt)</source>
      <translation>پروندهٔ متنی کد باز  (*.odt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="985" />
      <source>HTML files (*.html *.htm)</source>
      <translation>HTML files (*.html *.htm)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1005" />
      <source>Unrecognized paperSize setting "%s".</source>
      <translation>اندازهٔ صفحهٔ نامشخّص در تنظیمات "%s".</translation>
    </message>
    <message>
      <location filename="../window.py" line="1020" />
      <source>Export document to PDF</source>
      <translation>صدور به قالب PDF</translation>
    </message>
    <message>
      <location filename="../window.py" line="1022" />
      <source>PDF files (*.pdf)</source>
      <translation>PDF files (*.pdf)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1046" />
      <source>Print document</source>
      <translation>چاپ سند</translation>
    </message>
    <message>
      <location filename="../window.py" line="1070" />
      <source>Export document</source>
      <translation>خروج سند</translation>
    </message>
    <message>
      <location filename="../window.py" line="1090" />
      <source>Failed to execute the command:</source>
      <translation>اجرای این دستور ناموفّق بود:</translation>
    </message>
    <message>
      <location filename="../window.py" line="1126" />
      <source>Alt text</source>
      <translation>متن جایگزین</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <location filename="../window.py" line="1126" />
      <source>URL</source>
      <translation>نشانی وبگاه</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <source>Link text</source>
      <translation>متن پیوند</translation>
    </message>
    <message>
      <location filename="../window.py" line="1168" />
      <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
      <translation>این پرونده را برنامهٔ دیگری حذف کرده است.
لطفاً قبل از خروج خاطر جمع شوید که پرونده را ذخیره کرده‌اید.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1177" />
      <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
      <translation>این سند را برنامهٔ دیگری تغییر داده است.
می‌خواهید آن‌ها را دوباره بارگذاری کنید (این کار همهٔ تغییرات شما را از بین می‌برد)؟
</translation>
    </message>
    <message>
      <location filename="../window.py" line="1182" />
      <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
      <translation>ذخیرهٔ خودکار موقّتاً برای این سربرگ غیرفعّال شده است تا دادهها از دست نروند. هر گاه سند را دوباره باز کنید فعّال خواهد شد؛ یا می‌توانید سند را به صورت دستی ذخیره کنید.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1205" />
      <source>The document has been modified.
Do you want to save your changes?</source>
      <translation>سند تغییر کرده است. می‌خواهید آن ها را ذخیره کنید؟</translation>
    </message>
    <message>
      <location filename="../window.py" line="1232" />
      <source>HTML code</source>
      <translation>HTML code</translation>
    </message>
    <message>
      <location filename="../window.py" line="1243" />
      <source>Select one or several images to open</source>
      <translation>یک یا چند تصویر را برای باز کردن انتخاب کنید</translation>
    </message>
    <message>
      <location filename="../window.py" line="1264" />
      <source>ReText %s (using PyMarkups %s)</source>
      <translation>ReText %s (using PyMarkups %s)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1265" />
      <source>Simple but powerful editor for Markdown and reStructuredText</source>
      <translation>یک ویرایشگر متن ساده ولی توانمند برای ویرایش متن‌ در قالب‌های Markdown و reStructuredText</translation>
    </message>
    <message>
      <location filename="../window.py" line="1267" />
      <source>Author: Dmitry Shachnev, 2011</source>
      <translation>نگارنده: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
      <location filename="../window.py" line="1270" />
      <source>Markdown syntax</source>
      <translation>قواعد Markdown</translation>
    </message>
    <message>
      <location filename="../window.py" line="1272" />
      <source>reStructuredText syntax</source>
      <translation>قواعد reStructuredText</translation>
    </message>
  </context>
  <context>
    <name>TextInfoArea</name>
    <message>
      <location filename="../editor.py" line="659" />
      <source>%d w | %d a | %d c</source>
      <comment>count of words, alphanumeric characters, all characters</comment>
      <translation>%d w | %d a | %d c</translation>
    </message>
  </context>
  <context>
    <name>main</name>
    <message>
      <location filename="../__main__.py" line="84" />
      <source>Open the files in preview mode</source>
      <translation>باز کردن پرونده‌ها در حالت پیش‌نمایش</translation>
    </message>
    <message>
      <location filename="../__main__.py" line="86" />
      <source>Create a new window even if there is an existing one</source>
      <translation>ایجاد یک پنجرهٔ تازه، حتّی اگر یکی از قبل باشد</translation>
    </message>
    <message>
      <location filename="../__main__.py" line="90" />
      <source>List of files to open</source>
      <translation>فهرست پرونده‌های مورد نظر برای باز شدن</translation>
    </message>
  </context>
</TS>
